@@ -34,15 +34,13 @@ double ccbvalog(double m1, double m2, double oldm1, double dep, double asy1,
 
 double ccbvhr(double m1, double m2, double oldm1, double dep)
 {
-  double tm1,tm2,v,idep,q,fval;
+  double tm1,tm2,v,idep,fval;
 
   tm1 = -log(m1);
   tm2 = -log(m2);
   idep = 1 / dep;
   v = tm2 * pnorm(idep + (log(tm2) - log(tm1)) * dep/2, 0, 1, 1, 0) +
     tm1 * pnorm(idep + (log(tm1) - log(tm2)) * dep/2, 0, 1, 1, 0);
-  q = pnorm(idep + (log(tm2) - log(tm1)) * dep/2, 0, 1, 1, 0) *
-    exp(-v) / m2 - oldm1;
   fval = pnorm(idep + (log(tm2) - log(tm1)) * dep/2, 0, 1, 1, 0) *
     exp(-v) / m2 - oldm1;
   return fval;
@@ -79,19 +77,19 @@ double ccbvbilog(double m1, double m2, double oldm1, double alpha,
 {
   int i;
   double tm1,tm2,v,fval;
-  double delta,eps,llim,midpt,ulim,ilen,lval,midval,uval;
+  double delta,eps,llim,midpt,ilen,lval,midval,uval;
 
   tm1 = -log(m1);
   tm2 = -log(m2);
 
-  delta = eps = R_pow(DOUBLE_EPS, 0.75);
+  delta = eps = R_pow(DBL_EPSILON, 0.75);
   llim = 0;
-  ulim = ilen = 1;
+  ilen = 1;
   lval = (1 - alpha) * tm1;
   uval = (beta - 1) * tm2;
   if(!(sign(lval) != sign(uval))) 
     error("values at end points are not of opposite sign");
-  for(i=0;i<DOUBLE_DIGITS;i++) {
+  for(i=0;i<DBL_MANT_DIG;i++) {
     ilen = ilen/2;
     midpt = llim + ilen;
     midval = (1 - alpha) * tm1 * R_pow(1 - midpt, beta) - 
@@ -99,14 +97,13 @@ double ccbvbilog(double m1, double m2, double oldm1, double alpha,
     if(fabs(midval) < eps || fabs(ilen) < delta) 
       break;
     if(sign(lval) != sign(midval)) {
-      ulim = midpt;
       uval = midval;
     }
     else {
       llim = midpt;
       lval = midval;
     }
-  if(i == DOUBLE_DIGITS-1) 
+  if(i == DBL_MANT_DIG-1) 
     error("numerical problem in root finding algorithm");
   }
 
@@ -120,19 +117,19 @@ double ccbvnegbilog(double m1, double m2, double oldm1, double alpha,
 {
   int i;
   double tm1,tm2,v,fval;
-  double delta,eps,llim,midpt,ulim,ilen,lval,midval,uval;
+  double delta,eps,llim,midpt,ilen,lval,midval,uval;
 
   tm1 = -log(m1);
   tm2 = -log(m2);
 
-  delta = eps = R_pow(DOUBLE_EPS, 0.75);
+  delta = eps = R_pow(DBL_EPSILON, 0.75);
   llim = 0;
-  ulim = ilen = 1;
+  ilen = 1;
   lval = - (1 + beta) * tm2;
   uval = (1 + alpha) * tm1;
   if(!(sign(lval) != sign(uval))) 
     error("values at end points are not of opposite sign1");
-  for(i=0;i<DOUBLE_DIGITS;i++) {
+  for(i=0;i<DBL_MANT_DIG;i++) {
     ilen = ilen/2;
     midpt = llim + ilen;
     midval = (1 + alpha) * tm1 * R_pow(midpt, alpha) - 
@@ -140,14 +137,13 @@ double ccbvnegbilog(double m1, double m2, double oldm1, double alpha,
     if(fabs(midval) < eps || fabs(ilen) < delta) 
       break;
     if(sign(lval) != sign(midval)) {
-      ulim = midpt;
       uval = midval;
     }
     else {
       llim = midpt;
       lval = midval;
     }
-  if(i == DOUBLE_DIGITS-1) 
+  if(i == DBL_MANT_DIG-1) 
     error("numerical problem in root finding algorithm");
   }
 
